"""dtelecom-stt — Python SDK for dTelecom real-time speech-to-text with x402 micropayments."""

from .client import STTClient
from .exceptions import (
    AudioFormatError,
    ConnectionError,
    PaymentError,
    SessionExpiredError,
    STTError,
)
from .stream import Stream
from .types import PricingInfo, SessionInfo, Transcription

__all__ = [
    "STTClient",
    "Stream",
    "Transcription",
    "SessionInfo",
    "PricingInfo",
    "STTError",
    "PaymentError",
    "SessionExpiredError",
    "ConnectionError",
    "AudioFormatError",
]
