"""Exceptions for dtelecom-stt SDK."""


class STTError(Exception):
    """Base exception for all STT errors."""


class PaymentError(STTError):
    """Payment failed or insufficient funds."""


class SessionExpiredError(STTError):
    """Session time exhausted."""


class ConnectionError(STTError):
    """WebSocket or HTTP connection error."""


class AudioFormatError(STTError):
    """Invalid audio format (not PCM16, wrong sample rate, etc.)."""
